******************************************************************************
* This file looks at the aggregate exchange rate pass-through using micro data
******************************************************************************

clear
set mem 1000m


cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data"




use UnitValues_Firms_RER

replace cnaeprod = cnaefirm if cnaeprod == .
* Keep only manufacturing
keep if cnaefirm >= 15 & cnaefirm <= 37
keep if cnaeprod >= 15 & cnaeprod <= 37

* Drop those products that changed classification in 2002
* drop if ncm <= 1000

* Firm-Product-Country Fixed Effects
egen gp = group(cnpj ncm pais)

sort gp year

gen ones = 1

by gp year: egen totobs = total(ones)

drop if totobs > 1

tsset gp year

gen log_uv        = log(unitvalue1)
replace log_uv    = log(unitvalue2) if natural_measure1 == "QTD"
gen log_qtd       = log(pesoagg)
replace log_qtd   = log(qtdagg) if natural_measure1 == "QTD"

drop unitvalue* qtdagg pesoagg

gen log_rer         = log(rer)
gen log_lag_emp     = log(lag_emp)
gen log_cgdp        = log(cgdp)
gen log_gdp         = log(cgdp*pop)
gen log_lag_wage    = log(lag_wage)
gen log_lag_imports = log(1+lag_imports)
gen log_lag_exports = log(1+lag_exports)

drop total_emp cgdp avg_wage

* Merging Comtrade data on imports at destinations
gen HS6 = ncm
replace HS6 = int(ncm / 100) if ncm > 1000
sort country_isocode HS6 year
merge country_isocode HS6 year using importsMinusBRA
keep if _merge ~= 2
drop _merge
gen log_demand = log(1+1000.0*importsMinusBRA)
replace log_demand = 0 if log_demand == .
display _N

gen log_rer_emp     = log_rer*log_lag_emp
gen log_rer_skill   = log_rer*lag_skill
gen log_rer_wage    = log_rer*log_lag_wage
gen log_rer_imp     = log_rer*log_lag_imports
gen log_rer_exp     = log_rer*log_lag_exports
gen log_rer_dem     = log_rer*log_demand

gen t1 = year - 1997
gen t2 = (year - 1997)^2
gen t3 = (year - 1997)^3
gen t4 = (year - 1997)^4
gen t5 = (year - 1997)^5


drop if ncm == . | pais == "" | year == . | cnpj == ""

* Merge with IMR from the selection equation
sort ncm cnpj pais year
merge ncm cnpj pais year using IMR
keep if _merge == 3
drop _merge


* Year fixed effects
tab year, gen(year)


cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"

* ALL FIRMS
qui areg log_uv log_rer t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports ///
log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
outreg2 log_rer log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports ///
log_cgdp log_gdp log_demand using BasicRegressions, replace excel bdec(4) bracket ctitle("Prices")

qui areg log_qtd log_rer t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports ///
log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
outreg2 log_rer log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports ///
log_cgdp log_gdp log_demand using BasicRegressions, append excel bdec(4) bracket ctitle("Qty")


************************************************
* BMM type regressions with single product firms
************************************************

* Single Product Firms - logRER interactions
qui areg log_uv log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
     log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand t1 t2 t3 t4 t5 if num_prod == 1, absorb(gp) vce(cluster cnpj)
outreg2 log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
     log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using BMMRegressions, replace excel bdec(4) bracket ctitle("SingleProduct/Prices")

qui areg log_qtd log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
     log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand t1 t2 t3 t4 t5 if num_prod == 1, absorb(gp) vce(cluster cnpj)
outreg2 log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
     log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using BMMRegressions, append excel bdec(4) bracket ctitle("SingleProduct/Qty")


*****************************
* INDUSTRY SPECIFIC RESPONSES
*****************************

keep gp log_uv log_qtd log_rer t1 t2 t3 t4 t5 ///
     cnaeprod valoragg cnpj log_lag_emp lag_skill log_lag_wage log_lag_imports log_cgdp log_gdp log_lag_exports ///
	log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem num_prod log_demand

sort cnaeprod 

* Regressions industry by industry - Unit Values - with LogRER interactions
qui areg log_uv log_rer ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports ///
log_cgdp log_gdp log_demand if cnaeprod == 15, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports ///
log_cgdp log_gdp log_demand using UVRegressions_ByInd, replace excel bdec(4) bracket noaster ctitle("Industry 15")

forvalues i = 16(1)36 {
	qui areg log_uv log_rer ///
	t1 t2 t3 t4 t5 log_rer log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports ///
log_cgdp log_gdp log_demand log_cgdp log_gdp log_demand if cnaeprod == `i', absorb(gp) vce(cluster cnpj)
	qui outreg2 log_rer log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports ///
log_cgdp log_gdp log_demand log_cgdp log_gdp log_demand using UVRegressions_ByInd, append excel bdec(4) bracket noaster ctitle("Industry `i'")
}
