clear
set mem 1000m

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data"

******************************************************************************************************************************
* Keeps only those products which were always ranked first and those products which were never core, in order to avoid
* having products that changed ranking over the sample period.
******************************************************************************************************************************
use ppp_brazil
sort year
save ppp_brazil, replace


clear

use UnitValues_Firms_RER

replace cnaeprod = cnaefirm if cnaeprod == .
keep if cnaeprod >= 15 & cnaeprod <= 37
keep if cnaefirm >= 15 & cnaefirm <= 37
* drop if ncm <= 1000

* Firm-Product-Country Fixed Effects
egen gp = group(cnpj ncm pais)

sort gp year

gen ones = 1

by gp year: egen totobs = total(ones)

drop if totobs > 1

tsset gp year

gen log_uv        = log(unitvalue1)
replace log_uv    = log(unitvalue2) if natural_measure1 == "QTD"
gen log_qtd       = log(pesoagg)
replace log_qtd   = log(qtdagg) if natural_measure1 == "QTD"

gen log_rer         = log(rer)
gen log_lag_emp     = log(lag_emp)
gen log_cgdp        = log(cgdp)
gen log_gdp        = log(cgdp*pop)
gen log_lag_wage    = log(lag_wage)
gen log_lag_imports = log(1+lag_imports)
gen log_lag_exports = log(1+lag_exports)

* Merging Comtrade data on imports at destinations
gen HS6 = ncm
replace HS6 = int(ncm / 100) if ncm > 1000
sort country_isocode HS6 year
merge country_isocode HS6 year using importsMinusBRA
keep if _merge ~= 2
drop _merge
gen log_demand = log(1+1000.0*importsMinusBRA)
replace log_demand = 0 if log_demand == .
display _N

gen log_rer_emp    = log_rer*log_lag_emp
gen log_rer_skill  = log_rer*lag_skill
gen log_rer_wage   = log_rer*log_lag_wage
gen log_rer_imp    = log_rer*log_lag_imports
gen log_rer_exp    = log_rer*log_lag_exports
gen log_rer_dem    = log_rer*log_demand


gen t1 = year - 1997
gen t2 = (year - 1997)^2
gen t3 = (year - 1997)^3
gen t4 = (year - 1997)^4
gen t5 = (year - 1997)^5

**** Keep only firm-destination pairs with more than 1 product ****
* keep if num_prod > 1

**** Generate product ranking for each firm-destination-year triplet ****
gsort + cnpj + pais + year - valoragg
by cnpj pais year: gen ranking = _n
sort cnpj pais year
by cnpj pais year: egen median_ranking = median(ranking)


sort cnpj ncm pais

by cnpj ncm pais: egen min_ranking = min(ranking)
by cnpj ncm pais: egen max_ranking = max(ranking)

gen always_first = 0
replace always_first = 1 if min_ranking == 1 & max_ranking == 1

gen never_core = 0
replace never_core = 1 if min_ranking > 1

keep if always_first == 1 | never_core == 1

sort cnpj pais year

by cnpj pais year: egen min_always_first = min(always_first)
by cnpj pais year: egen max_always_first = max(always_first)
by cnpj pais year: egen min_never_core = min(never_core)
by cnpj pais year: egen max_never_core = max(never_core)

* Keep cnpj-pais-year combinations that have one product always_first 
* and at least on product never_core
keep if min_always_first == 0
keep if max_always_first == 1
keep if min_never_core   == 0
keep if max_never_core   == 1

* Not the core product
gen never_core_log_rer  = never_core*log_rer

drop valoragg qtdagg pesoagg unitvalue1 unitvalue2 natural_measure1 natural_measure2 ///
total_emp avg_wage fraction_skilled valorimpusd country_isocode pop rer nomer lag_rer ///
xrat_bra ppp_bra imports lag_imports

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"

qui areg log_uv log_rer never_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer never_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_cgdp log_gdp log_demand using ProductLadderRobust1, replace excel bdec(4) bracket ///
    ctitle("AlwaysCore/NeverCore")




******************************************************************************************************************************
* time invariant ranking - total sales over the years for each firm-destination pair
******************************************************************************************************************************


clear
set mem 1000m

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data"

clear
use ranking
keep pais ncm cnpj ranking2
rename ranking2 ranking
duplicates drop
sort cnpj pais 
by cnpj pais: egen median_ranking = median(ranking)
sort cnpj pais ncm
save ranking2, replace


use UnitValues_Firms_RER

replace cnaeprod = cnaefirm if cnaeprod == .
keep if cnaeprod >= 15 & cnaeprod <= 37
keep if cnaefirm >= 15 & cnaefirm <= 37
* drop if ncm <= 1000


sort cnpj pais ncm
merge cnpj pais ncm using ranking2
keep if _merge == 1 | _merge == 3
drop _merge

gen log_uv        = log(unitvalue1)
replace log_uv    = log(unitvalue2) if natural_measure1 == "QTD"
gen log_qtd       = log(pesoagg)
replace log_qtd   = log(qtdagg) if natural_measure1 == "QTD"


gen log_rer         = log(rer)
gen log_lag_emp     = log(lag_emp)
gen log_cgdp        = log(cgdp)
gen log_gdp        = log(cgdp*pop)
gen log_lag_wage    = log(lag_wage)
gen log_lag_imports = log(1+lag_imports)
gen log_lag_exports = log(1+lag_exports)

* Merging Comtrade data on imports at destinations
gen HS6 = ncm
replace HS6 = int(ncm / 100) if ncm > 1000
sort country_isocode HS6 year
merge country_isocode HS6 year using importsMinusBRA
keep if _merge ~= 2
drop _merge
gen log_demand = log(1+1000.0*importsMinusBRA)
replace log_demand = 0 if log_demand == .
display _N

gen log_rer_emp    = log_rer*log_lag_emp
gen log_rer_skill  = log_rer*lag_skill
gen log_rer_wage   = log_rer*log_lag_wage
gen log_rer_imp    = log_rer*log_lag_imports
gen log_rer_exp    = log_rer*log_lag_exports
gen log_rer_dem    = log_rer*log_demand

gen t1 = year - 1997
gen t2 = (year - 1997)^2
gen t3 = (year - 1997)^3
gen t4 = (year - 1997)^4
gen t5 = (year - 1997)^5

* keep if num_prod > 1

* Below Median
gen bottom_log_rer = (ranking > median_ranking)*log_rer
* Not the core product
gen not_core_log_rer  = (ranking > 1)*log_rer
* Second product
gen second_log_rer = (ranking == 2)*log_rer
* Ranking
gen ranking_log_rer = ranking*log_rer
* log(ranking)
gen log_ranking_log_rer = log(ranking)*log_rer

egen gp = group(cnpj ncm pais)

drop if ncm == . | pais == "" | year == . | cnpj == ""

* Merge with IMR from the selection equation
sort ncm cnpj pais year
merge ncm cnpj pais year using IMR
keep if _merge == 3
drop _merge

drop valoragg qtdagg pesoagg unitvalue1 unitvalue2 natural_measure1 natural_measure2 ///
total_emp avg_wage fraction_skilled valorimpusd country_isocode pop rer nomer lag_rer ///
xrat_bra ppp_bra imports lag_imports  

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"

qui areg log_uv log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderRobust2, replace excel bdec(4) bracket ///
    ctitle("Top/Bottom")


qui areg log_uv log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderRobust2, append excel bdec(4) bracket ///
    ctitle("Core/NotCore")


qui areg log_uv log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand if ranking <= 2, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderRobust2, append excel bdec(4) bracket ///
    ctitle("First/Second")


qui areg log_uv log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderRobust2, append excel bdec(4) bracket ///
    ctitle("LogRanking")
	
	
	
	
qui areg log_uv log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR using ProductLadderRobust3, replace excel bdec(4) bracket ///
    ctitle("Top/Bottom")


qui areg log_uv log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR using ProductLadderRobust3, append excel bdec(4) bracket ///
    ctitle("Core/NotCore")


qui areg log_uv log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR if ranking <= 2, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR using ProductLadderRobust3, append excel bdec(4) bracket ///
    ctitle("First/Second")


qui areg log_uv log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR using ProductLadderRobust3, append excel bdec(4) bracket ///
    ctitle("LogRanking")	




	
	
	
	
	
	
	
	