clear
set mem 1000m

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data"

******************************************************************************************************************************
* Keeps only those firm-product-destination triplets always active in the sample
******************************************************************************************************************************

use UnitValues_Firms_RER

replace cnaeprod = cnaefirm if cnaeprod == .
keep if cnaefirm >= 15 & cnaefirm <= 37
keep if cnaeprod >= 15 & cnaeprod <= 37

* drop if ncm <= 1000
* drop if year == 2001

keep ncm cnpj pais year

duplicates drop

gen ones = 1

sort ncm cnpj pais
by ncm cnpj pais: egen totobs2 = sum(ones)

keep if totobs2 >= 9

keep ncm cnpj pais

sort ncm cnpj pais

save aux1, replace





clear

use UnitValues_Firms_RER

replace cnaeprod = cnaefirm if cnaeprod == .
keep if cnaefirm >= 15 & cnaefirm <= 37
keep if cnaeprod >= 15 & cnaeprod <= 37
* drop if ncm <= 1000
* drop if year == 2001

sort ncm cnpj pais

merge ncm cnpj pais using aux1

keep if _merge == 3

drop _merge

* Firm-Product-Country Fixed Effects
egen gp = group(cnpj ncm pais)


sort gp year
gen ones = 1
by gp year: egen totobs = total(ones)
drop if totobs > 1
tsset gp year


gen log_uv        = log(unitvalue1)
replace log_uv    = log(unitvalue2) if natural_measure1 == "QTD"
gen log_qtd       = log(pesoagg)
replace log_qtd   = log(qtdagg) if natural_measure1 == "QTD"


drop unitvalue* qtdagg pesoagg


gen log_rer         = log(rer)
gen log_lag_emp     = log(lag_emp)
gen log_cgdp        = log(cgdp)
gen log_gdp        = log(cgdp*pop)
gen log_lag_wage    = log(lag_wage)
gen log_lag_imports = log(1+lag_imports)
gen log_lag_exports = log(1+lag_exports)


drop total_emp cgdp avg_wage imports


* Merging Comtrade data on imports at destinations
gen HS6 = ncm
replace HS6 = int(ncm / 100) if ncm > 1000
sort country_isocode HS6 year
merge country_isocode HS6 year using importsMinusBRA
keep if _merge ~= 2
drop _merge
gen log_demand = log(1+1000.0*importsMinusBRA)
replace log_demand = 0 if log_demand == .
display _N

gen log_rer_emp    = log_rer*log_lag_emp
gen log_rer_skill  = log_rer*lag_skill
gen log_rer_wage   = log_rer*log_lag_wage
gen log_rer_imp    = log_rer*log_lag_imports
gen log_rer_exp    = log_rer*log_lag_exports
gen log_rer_dem    = log_rer*log_demand


gen t1 = year - 1997
gen t2 = (year - 1997)^2
gen t3 = (year - 1997)^3
gen t4 = (year - 1997)^4
gen t5 = (year - 1997)^5



**** Keep only firm-destination pairs with more than 1 product ****
* keep if num_prod > 1


**** Generate product ranking for each firm-destination-year triplet ****
gsort + cnpj + pais + year - valoragg
by cnpj pais year: gen ranking = _n
sort cnpj pais year
by cnpj pais year: egen median_ranking = median(ranking)


****************
* INTERACTIONS *
****************

**** Interactions of Log RER with Product Rankings ****
* Below Median
gen bottom_log_rer = (ranking > median_ranking)*log_rer
* Not the core product
gen not_core_log_rer  = (ranking > 1)*log_rer
* Second product
gen second_log_rer = (ranking == 2)*log_rer
* Ranking
gen ranking_log_rer = ranking*log_rer
* log(ranking)
gen log_ranking_log_rer = log(ranking)*log_rer



*****************************************************************************************************************************************
*****************************************************************************************************************************************



cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"

drop totobs valorimpusd country_isocode

* Top/Bottom w/ Interactions
qui areg    log_uv log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
	       t1 t2 t3 t4 t5 ///
            log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderRobust4, replace excel bdec(4) bracket ///
    ctitle("Top/Bottom")


qui areg    log_uv log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
	       t1 t2 t3 t4 t5 ///
            log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderRobust4, append excel bdec(4) bracket ///
    ctitle("Core/NotCore")


qui areg  log_uv log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
	       t1 t2 t3 t4 t5 ///
            log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand if ranking <= 2, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderRobust4, append excel bdec(4) bracket ///
    ctitle("Top/Bottom")


qui areg  log_uv log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
	       t1 t2 t3 t4 t5 ///
            log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_exp log_rer_dem ///
    log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderRobust4, append excel bdec(4) bracket ///
    ctitle("Top/Bottom")

clear
