clear
set mem 800m

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data"

use rmp_cepii
keep iso year RMP_HM
rename iso country_isocode
sort country_isocode year
save market_potential, replace


clear
use XRAT_VOL
sort country_isocode
save XRAT_VOL, replace



clear
use brazildistance
keep country_isocode dist
replace country_isocode = "GER" if country_isocode == "DEU"
sort country_isocode
save brazildistance2, replace



clear
use cnae2-dist_int
sort cnaeprod
save cnae2-dist_int, replace



clear
use UnitValues_Firms_RER

replace cnaeprod = cnaefirm if cnaeprod == .
keep if cnaeprod >= 15 & cnaeprod <= 37
keep if cnaefirm >= 15 & cnaefirm <= 37
* drop if ncm <= 1000


sort country_isocode
merge country_isocode using XRAT_VOL
keep if _merge == 3 | _merge == 1
drop _merge


sort country_isocode
merge country_isocode using brazildistance2
keep if _merge == 3 | _merge == 1
drop _merge



sort cnaeprod
merge cnaeprod using cnae2-dist_int
keep if _merge == 3 | _merge == 1
drop _merge




sort cnpj year
merge cnpj year using ExperienceExporting
keep if _merge == 3 | _merge == 1
drop _merge
duplicates drop



* Firm-Product-Country Fixed Effects
egen gp = group(cnpj ncm pais)

sort gp year

gen ones = 1

by gp year: egen totobs = total(ones)

drop if totobs > 1

tsset gp year

gen log_uv        = log(unitvalue1)
replace log_uv    = log(unitvalue2) if natural_measure1 == "QTD"
gen log_qtd       = log(pesoagg)
replace log_qtd   = log(qtdagg) if natural_measure1 == "QTD"

drop unitvalue* qtdagg pesoagg


gen log_rer         = log(rer)
gen log_lag_emp     = log(lag_emp)
gen log_cgdp        = log(cgdp)
gen log_gdp         = log(cgdp*pop)
gen log_lag_wage    = log(lag_wage)
gen log_lag_imports = log(1+lag_imports)
gen log_lag_exports = log(1+lag_exports)
gen log_lag_experience = log(1+experience)

drop total_emp cgdp avg_wage imports

gen log_rer_emp            = log_rer*log_lag_emp
gen log_rer_skill          = log_rer*lag_skill
gen log_rer_wage           = log_rer*log_lag_wage
gen log_rer_imp            = log_rer*log_lag_imports
gen log_rer_exp            = log_rer*log_lag_exports
gen log_rer_dist           = log_rer*log(dist)
gen log_rer_distmg         = log_rer*log(dist_int)
gen log_rer_xrat_vol       = log_rer*xrat_vol
gen log_rer_experience     = log_rer*log(1+experience)
gen log_rer_gdp            = log_rer*log_gdp


gen t1 = year - 1997
gen t2 = (year - 1997)^2
gen t3 = (year - 1997)^3
gen t4 = (year - 1997)^4
gen t5 = (year - 1997)^5

gen lag_num_prod = L.num_prod
replace lag_num_prod = 0 if lag_num_prod == .
replace lag_num_prod = num_prod if year == 1997

gen lag_dest = lag_totdest

gen log_rer_log_num_prod = log_rer*log(1+lag_num_prod)
gen log_num_prod         = log(1+lag_num_prod)
gen log_rer_dest         = log_rer*log(1+lag_dest)


* Merging Comtrade data on imports at destinations
gen HS6 = ncm
replace HS6 = int(ncm / 100) if ncm > 1000
sort country_isocode HS6 year
merge country_isocode HS6 year using importsMinusBRA
keep if _merge ~= 2
drop _merge
gen log_demand = log(1+1000.0*importsMinusBRA)
replace log_demand = 0 if log_demand == .
display _N
gen log_rer_dem = log_rer*log_demand

**** Keep only firm-destination pairs with more than 1 product ****
* keep if num_prod > 1


**** Generate product ranking for each firm-destination-year triplet ****
gsort + cnpj + pais + year - valoragg
by cnpj pais year: gen ranking = _n
sort cnpj pais year
by cnpj pais year: egen median_ranking = median(ranking)

****************
* INTERACTIONS *
****************


**** Interactions of Log RER with Product Rankings ****
* Below Median
gen bottom_log_rer = (ranking > median_ranking)*log_rer
* Not the core product
gen not_core_log_rer  = (ranking > 1)*log_rer
* Second product
gen second_log_rer = (ranking == 2)*log_rer
* Ranking
gen ranking_log_rer = ranking*log_rer
* log(ranking)
gen log_ranking_log_rer = log(ranking)*log_rer


* Merge with IMR from the selection equation
sort ncm cnpj pais year
merge ncm cnpj pais year using IMR
keep if _merge == 3
drop _merge


*****************************************************************************************************************************************
*****************************************************************************************************************************************



cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"

qui areg log_uv log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_experience log_rer_log_num_prod log_rer_dest log_rer_dem ///
          log_rer_gdp log_rer_dist log_rer_distmg log_rer_xrat_vol ///
          t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_lag_experience log_num_prod lag_dest ///
		  log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
		 
qui outreg2 log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_experience log_rer_log_num_prod log_rer_dest log_rer_dem ///
            log_rer_gdp log_rer_dist log_rer_distmg log_rer_xrat_vol ///
            t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_lag_experience log_num_prod lag_dest ///
	  	    log_cgdp log_gdp log_demand ///
            using Decomposition, replace excel bdec(4) bracket ctitle("Top/Bottom")		 



qui areg  log_uv log_rer not_core_log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_experience log_rer_log_num_prod log_rer_dest log_rer_dem ///
          log_rer_gdp log_rer_dist log_rer_distmg log_rer_xrat_vol ///
          t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_lag_experience log_num_prod lag_dest ///
		  log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)

qui outreg2 log_rer not_core_log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_experience log_rer_log_num_prod log_rer_dest log_rer_dem ///
            log_rer_gdp log_rer_dist log_rer_distmg log_rer_xrat_vol ///
            t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_lag_experience log_num_prod lag_dest ///
		    log_cgdp log_gdp log_demand ///
            using Decomposition, append excel bdec(4) bracket ctitle("Core/NotCore")




qui areg  log_uv log_rer second_log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_experience log_rer_log_num_prod log_rer_dest log_rer_dem ///
          log_rer_gdp log_rer_dist log_rer_distmg log_rer_xrat_vol ///
          t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_lag_experience log_num_prod lag_dest ///
		  log_cgdp log_gdp log_demand if ranking <= 2, absorb(gp) vce(cluster cnpj)

qui outreg2 log_rer second_log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_experience log_rer_log_num_prod log_rer_dest log_rer_dem ///
            log_rer_gdp log_rer_dist log_rer_distmg log_rer_xrat_vol ///
            t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_lag_experience log_num_prod lag_dest ///
		    log_cgdp log_gdp log_demand ///
            using Decomposition, append excel bdec(4) bracket ctitle("First/Second")


qui areg  log_uv log_rer log_ranking_log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_experience log_rer_log_num_prod log_rer_dest log_rer_dem ///
          log_rer_gdp log_rer_dist log_rer_distmg log_rer_xrat_vol ///
          t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_lag_experience log_num_prod lag_dest ///
		  log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)

qui outreg2 log_rer log_ranking_log_rer log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_experience log_rer_log_num_prod log_rer_dest log_rer_dem ///
            log_rer_gdp log_rer_dist log_rer_distmg log_rer_xrat_vol ///
            t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_lag_experience log_num_prod lag_dest ///
		    log_cgdp log_gdp log_demand ///
            using Decomposition, append excel bdec(4) bracket ctitle("LogRanking")
			
			
cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data"
			
sort country_isocode year
merge country_isocode year using market_potential
keep if _merge == 3 | _merge == 1
drop _merge			

gen log_rer_mkt_pot = log_rer*log(RMP_HM)
gen log_mkt_pot = log(RMP_HM)

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"

qui areg log_uv log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem log_rer_experience log_rer_log_num_prod log_rer_dest ///
         log_rer_mkt_pot log_rer_dist log_rer_distmg log_rer_xrat_vol ///
         t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_num_prod log_lag_experience lag_dest ///
		 log_cgdp log_gdp log_mkt_pot log_demand, absorb(gp) vce(cluster cnpj)
		 
qui outreg2 log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem log_rer_experience log_rer_log_num_prod log_rer_dest ///
            log_rer_mkt_pot log_rer_dist log_rer_distmg log_rer_xrat_vol ///
            t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_num_prod log_lag_experience lag_dest log_cgdp log_gdp log_mkt_pot log_demand ///
            using Decomposition2, replace excel bdec(4) bracket ctitle("Top/Bottom")
			
						
qui areg log_uv log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem log_rer_experience log_rer_log_num_prod log_rer_dest ///
         log_rer_mkt_pot log_rer_dist log_rer_distmg log_rer_xrat_vol ///
         t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_num_prod log_lag_experience lag_dest ///
		 log_cgdp log_gdp log_mkt_pot log_demand, absorb(gp) vce(cluster cnpj)
		 
qui outreg2 log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem log_rer_experience log_rer_log_num_prod log_rer_dest ///
            log_rer_mkt_pot log_rer_dist log_rer_distmg log_rer_xrat_vol ///
            t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_num_prod log_lag_experience lag_dest log_cgdp log_gdp log_mkt_pot log_demand ///
            using Decomposition2, append excel bdec(4) bracket ctitle("Core/NotCore")
			
			
qui areg log_uv log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem log_rer_experience log_rer_log_num_prod log_rer_dest ///
         log_rer_mkt_pot log_rer_dist log_rer_distmg log_rer_xrat_vol ///
         t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_num_prod log_lag_experience lag_dest ///
		 log_cgdp log_gdp log_mkt_pot log_demand if ranking <= 2, absorb(gp) vce(cluster cnpj)
		 
qui outreg2 log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem log_rer_experience log_rer_log_num_prod log_rer_dest ///
            log_rer_mkt_pot log_rer_dist log_rer_distmg log_rer_xrat_vol ///
            t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_num_prod log_lag_experience lag_dest log_cgdp log_gdp log_mkt_pot log_demand ///
            using Decomposition2, append excel bdec(4) bracket ctitle("First/Second")
			
			
qui areg log_uv log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem log_rer_experience log_rer_log_num_prod log_rer_dest ///
         log_rer_mkt_pot log_rer_dist log_rer_distmg log_rer_xrat_vol ///
         t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_num_prod log_lag_experience lag_dest ///
		 log_cgdp log_gdp log_mkt_pot log_demand, absorb(gp) vce(cluster cnpj)
		 
qui outreg2 log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem log_rer_experience log_rer_log_num_prod log_rer_dest ///
            log_rer_mkt_pot log_rer_dist log_rer_distmg log_rer_xrat_vol ///
            t1 t2 t3 t4 t5 log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_num_prod log_lag_experience lag_dest log_cgdp log_gdp log_mkt_pot log_demand ///
            using Decomposition2, append excel bdec(4) bracket ctitle("Log Ranking")			
