clear
set mem 1000m

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data"

*use ranking
*keep cnpj pais ncm ranking2



use UnitValues_Firms_RER

replace cnaeprod = cnaefirm if cnaeprod == .
* Keep only Manufacturing
keep if cnaefirm >= 15 & cnaefirm <= 37
keep if cnaeprod >= 15 & cnaeprod <= 37


* Drop those products that changed classification in 2002
* drop if ncm <= 1000


* Firm-Product-Country Fixed Effects
egen gp = group(cnpj ncm pais)


sort gp year
gen ones = 1
by gp year: egen totobs = total(ones)
drop if totobs > 1
tsset gp year


gen log_uv        = log(unitvalue1)
replace log_uv    = log(unitvalue2) if natural_measure1 == "QTD"
gen log_qtd       = log(pesoagg)
replace log_qtd   = log(qtdagg) if natural_measure1 == "QTD"


drop unitvalue* qtdagg pesoagg


gen log_rer         = log(rer)
gen log_lag_emp     = log(lag_emp)
gen log_cgdp        = log(cgdp)
gen log_gdp        = log(cgdp*pop)
gen log_lag_wage    = log(lag_wage)
gen log_lag_imports = log(1+lag_imports)
gen log_lag_exports = log(1+lag_exports)


drop total_emp cgdp avg_wage imports


* Merging Comtrade data on imports at destinations
gen HS6 = ncm
replace HS6 = int(ncm / 100) if ncm > 1000
sort country_isocode HS6 year
merge country_isocode HS6 year using importsMinusBRA
keep if _merge ~= 2
drop _merge
gen log_demand = log(1+1000.0*importsMinusBRA)
replace log_demand = 0 if log_demand == .
display _N

gen log_rer_emp    = log_rer*log_lag_emp
gen log_rer_skill  = log_rer*lag_skill
gen log_rer_wage   = log_rer*log_lag_wage
gen log_rer_imp    = log_rer*log_lag_imports
gen log_rer_exp    = log_rer*log_lag_exports
gen log_rer_dem    = log_rer*log_demand


gen t1 = year - 1997
gen t2 = (year - 1997)^2
gen t3 = (year - 1997)^3
gen t4 = (year - 1997)^4
gen t5 = (year - 1997)^5

count if ncm <= 1000
display _N
**** Generate product ranking for each firm-destination-year triplet ****
gsort + cnpj + pais + year - valoragg
by cnpj pais year: gen ranking = _n
* sort cnpj pais ncm
* merge cnpj pais ncm using ranking2
* keep if _merge == 1 | _merge == 3
* drop _merge


sort cnpj pais year
by cnpj pais year: egen median_ranking = median(ranking)
display _N
count if ncm <= 1000

****************
* INTERACTIONS *
****************

**** Interactions of Log RER with Product Rankings ****
* Below Median
gen bottom_log_rer = (ranking > median_ranking)*log_rer
* Not the core product
gen not_core_log_rer  = (ranking > 1)*log_rer
* Second product
gen second_log_rer = (ranking == 2)*log_rer
* Ranking
gen ranking_log_rer = ranking*log_rer
* log(ranking)
gen log_ranking_log_rer = log(ranking)*log_rer


* Merge with IMR from the selection equation
sort ncm cnpj pais year
merge ncm cnpj pais year using IMR
keep if _merge == 3
drop _merge



*****************************************************************************************************************************************
*****************************************************************************************************************************************



cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"

drop totobs valorimpusd country_isocode

* Top/Bottom w/ Interactions
qui areg    log_uv log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
	        t1 t2 t3 t4 t5 ///
            log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer bottom_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem IMR ///
            using ProductLadder_IMR, replace excel bdec(4) bracket ctitle("Bottom/Top")

* Core/NotCore w/ Interactions
qui areg    log_uv log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
	        t1 t2 t3 t4 t5 ///
            log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer not_core_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem IMR ///
            using ProductLadder_IMR, append excel bdec(4) bracket ctitle("Core/NotCore")

* First/Second w/ Interactions
qui areg    log_uv log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
	        t1 t2 t3 t4 t5 ///
            log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR if ranking <= 2, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer second_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem IMR ///
            using ProductLadder_IMR, append excel bdec(4) bracket ctitle("First/Second")

* LogRanking w/ Interactions
qui areg    log_uv log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem ///
	        t1 t2 t3 t4 t5 ///
            log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand IMR, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer log_ranking_log_rer log_rer_emp log_rer_skill log_rer_wage log_rer_imp log_rer_exp log_rer_dem IMR ///
            using ProductLadder_IMR, append excel bdec(4) bracket ctitle("Log Ranking")
