clear
set mem 1000m

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data"


use UnitValues_Firms_RER

replace cnaeprod = cnaefirm if cnaeprod == .
* Keep only Manufacturing
keep if cnaefirm >= 15 & cnaefirm <= 37
keep if cnaeprod >= 15 & cnaeprod <= 37


* Drop those products that changed classification in 2002
* drop if ncm <= 1000


* Firm-Product-Country Fixed Effects
egen gp = group(cnpj ncm pais)


sort gp year
gen ones = 1
by gp year: egen totobs = total(ones)
drop if totobs > 1
tsset gp year


gen log_uv        = log(unitvalue1)
replace log_uv    = log(unitvalue2) if natural_measure1 == "QTD"
gen log_qtd       = log(pesoagg)
replace log_qtd   = log(qtdagg) if natural_measure1 == "QTD"


drop unitvalue* qtdagg pesoagg


gen log_rer         = log(rer)
gen log_lag_emp     = log(lag_emp)
gen log_cgdp        = log(cgdp)
gen log_gdp         = log(cgdp*pop)
gen log_lag_wage    = log(lag_wage)
gen log_lag_imports = log(1+lag_imports)
gen log_lag_exports = log(1+lag_exports)


drop total_emp cgdp avg_wage imports

* Merging Comtrade data on imports at destinations
gen HS6 = ncm
replace HS6 = int(ncm / 100) if ncm > 1000
sort country_isocode HS6 year
merge country_isocode HS6 year using importsMinusBRA
keep if _merge ~= 2
drop _merge
gen log_demand = log(1+1000.0*importsMinusBRA)
replace log_demand = 0 if log_demand == .
display _N


gen log_rer_emp    = log_rer*log_lag_emp
gen log_rer_skill  = log_rer*lag_skill
gen log_rer_wage   = log_rer*log_lag_wage
gen log_rer_imp    = log_rer*log_lag_imports
gen log_rer_exp    = log_rer*log_lag_exports
gen log_rer_dem    = log_rer*log_demand

gen lag_log_rer        = log(lag_rer)
gen lag_log_rer_emp    = lag_log_rer*log_lag_emp
gen lag_log_rer_skill  = lag_log_rer*lag_skill
gen lag_log_rer_wage   = lag_log_rer*log_lag_wage
gen lag_log_rer_imp    = lag_log_rer*log_lag_imports
gen lag_log_rer_exp    = lag_log_rer*log_lag_exports
gen lag_log_rer_dem    = lag_log_rer*log_demand

gen lag2_log_rer        = log(lag2_rer)
gen lag2_log_rer_emp    = lag2_log_rer*log_lag_emp
gen lag2_log_rer_skill  = lag2_log_rer*lag_skill
gen lag2_log_rer_wage   = lag2_log_rer*log_lag_wage
gen lag2_log_rer_imp    = lag2_log_rer*log_lag_imports
gen lag2_log_rer_exp    = lag2_log_rer*log_lag_exports
gen lag2_log_rer_dem    = lag2_log_rer*log_demand


gen t1 = year - 1997
gen t2 = (year - 1997)^2
gen t3 = (year - 1997)^3
gen t4 = (year - 1997)^4
gen t5 = (year - 1997)^5


**** Generate product ranking for each firm-destination-year triplet ****
gsort + cnpj + pais + year - valoragg
by cnpj pais year: gen ranking = _n
sort cnpj pais year
by cnpj pais year: egen median_ranking = median(ranking)


****************
* INTERACTIONS *
****************

**** Interactions of Log RER with Product Rankings ****
* Below Median
**** Interactions of Log RER with Product Rankings ****
* Below Median
gen bottom_log_rer = (ranking > median_ranking)*log_rer
gen bottom_lag_log_rer = (ranking > median_ranking)*lag_log_rer
gen bottom_lag2_log_rer = (ranking > median_ranking)*lag2_log_rer
* Not the core product
gen not_core_log_rer  = (ranking > 1)*log_rer
gen not_core_lag_log_rer  = (ranking > 1)*lag_log_rer
gen not_core_lag2_log_rer  = (ranking > 1)*lag2_log_rer
* Not the core product
gen log_ranking_log_rer  = log(ranking)*log_rer
gen log_ranking_lag_log_rer  = log(ranking)*lag_log_rer
gen log_ranking_lag2_log_rer  = log(ranking)*lag2_log_rer

drop if ncm == . | pais == "" | year == . | cnpj == ""

* Merge with IMR from the selection equation
sort ncm cnpj pais year
merge ncm cnpj pais year using IMR
keep if _merge == 3
drop _merge



*****************************************************************************************************************************************
*****************************************************************************************************************************************



cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"


matrix sum = J(2,23,0)	

qui areg    log_uv log_rer lag_log_rer lag2_log_rer ///
        t1 t2 t3 t4 t5 ///
        log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer lag_log_rer lag2_log_rer ///
log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ResponseWithLags, replace excel bdec(4) bracket ///
ctitle("prices")

matrix V = e(V)
matrix a = J(1,17,0)
forvalues i = 1(1)3{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,1] = e(b)*a'
matrix sum[2,1] = sqrt(C[1,1])


qui areg    log_qtd log_rer lag_log_rer lag2_log_rer ///
        t1 t2 t3 t4 t5 ///
        log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
qui outreg2 log_rer lag_log_rer lag2_log_rer ///
log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ResponseWithLags, append excel bdec(4) bracket ///
    ctitle("quantity")

matrix V = e(V)
matrix a = J(1,17,0)
forvalues i = 1(1)3{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,2] = e(b)*a'
matrix sum[2,2] = sqrt(C[1,1])





qui areg    log_uv log_rer lag_log_rer lag2_log_rer ///
        bottom_log_rer bottom_lag_log_rer bottom_lag2_log_rer ///
	    log_rer_emp lag_log_rer_emp lag2_log_rer_emp  ///
		log_rer_skill lag_log_rer_skill lag2_log_rer_skill  ///
		log_rer_wage lag_log_rer_wage lag2_log_rer_wage ///
        log_rer_imp lag_log_rer_imp lag2_log_rer_imp ///
		log_rer_exp lag_log_rer_exp lag2_log_rer_exp ///
		log_rer_dem lag_log_rer_dem lag2_log_rer_dem ///
	    t1 t2 t3 t4 t5 ///
        log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
		
		
qui outreg2 log_rer lag_log_rer lag2_log_rer ///
        bottom_log_rer bottom_lag_log_rer bottom_lag2_log_rer ///
	    log_rer_emp lag_log_rer_emp lag2_log_rer_emp  ///
		log_rer_skill lag_log_rer_skill lag2_log_rer_skill  ///
		log_rer_wage lag_log_rer_wage lag2_log_rer_wage ///
        log_rer_imp lag_log_rer_imp lag2_log_rer_imp ///
		log_rer_exp lag_log_rer_exp lag2_log_rer_exp ///
		log_rer_dem lag_log_rer_dem lag2_log_rer_dem ///
	    t1 t2 t3 t4 t5 ///
        log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderWithLags, replace excel bdec(4) bracket ///
        ctitle("Top/Bottom")
		
	

* log_rer long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 1(1)3{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,3] = e(b)*a'
matrix sum[2,3] = sqrt(C[1,1])


* bottom_log_rer long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 4(1)6{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,4] = e(b)*a'
matrix sum[2,4] = sqrt(C[1,1])


* log_rer_emp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 7(1)9{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,5] = e(b)*a'
matrix sum[2,5] = sqrt(C[1,1])



* log_rer_skill long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 10(1)12{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,6] = e(b)*a'
matrix sum[2,6] = sqrt(C[1,1])



* log_rer_wage long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 13(1)15{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,7] = e(b)*a'
matrix sum[2,7] = sqrt(C[1,1])



* log_rer_imp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 16(1)18{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,8] = e(b)*a'
matrix sum[2,8] = sqrt(C[1,1])


* log_rer_exp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 19(1)21{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,9] = e(b)*a'
matrix sum[2,9] = sqrt(C[1,1])





qui areg    log_uv log_rer lag_log_rer lag2_log_rer ///
        not_core_log_rer not_core_lag_log_rer not_core_lag2_log_rer ///
	    log_rer_emp lag_log_rer_emp lag2_log_rer_emp  ///
		log_rer_skill lag_log_rer_skill lag2_log_rer_skill  ///
		log_rer_wage lag_log_rer_wage lag2_log_rer_wage ///
        log_rer_imp lag_log_rer_imp lag2_log_rer_imp ///
		log_rer_exp lag_log_rer_exp lag2_log_rer_exp ///
		log_rer_dem lag_log_rer_dem lag2_log_rer_dem ///
	    t1 t2 t3 t4 t5 ///
        log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
		
		
qui outreg2 log_rer lag_log_rer lag2_log_rer ///
        not_core_log_rer not_core_lag_log_rer not_core_lag2_log_rer ///
	    log_rer_emp lag_log_rer_emp lag2_log_rer_emp  ///
		log_rer_skill lag_log_rer_skill lag2_log_rer_skill  ///
		log_rer_wage lag_log_rer_wage lag2_log_rer_wage ///
        log_rer_imp lag_log_rer_imp lag2_log_rer_imp ///
		log_rer_exp lag_log_rer_exp lag2_log_rer_exp ///
		log_rer_dem lag_log_rer_dem lag2_log_rer_dem ///
	    t1 t2 t3 t4 t5 ///
        log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderWithLags, append excel bdec(4) bracket ///
        ctitle("Core/NotCore")
		
		
		
* log_rer long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 1(1)3{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,10] = e(b)*a'
matrix sum[2,10] = sqrt(C[1,1])


* bottom_log_rer long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 4(1)6{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,11] = e(b)*a'
matrix sum[2,11] = sqrt(C[1,1])


* log_rer_emp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 7(1)9{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,12] = e(b)*a'
matrix sum[2,12] = sqrt(C[1,1])



* log_rer_skill long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 10(1)12{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,13] = e(b)*a'
matrix sum[2,13] = sqrt(C[1,1])



* log_rer_wage long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 13(1)15{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,14] = e(b)*a'
matrix sum[2,14] = sqrt(C[1,1])



* log_rer_imp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 16(1)18{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,15] = e(b)*a'
matrix sum[2,15] = sqrt(C[1,1])


* log_rer_exp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 19(1)21{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,16] = e(b)*a'
matrix sum[2,16] = sqrt(C[1,1])
		
		
qui areg    log_uv log_rer lag_log_rer lag2_log_rer ///
        log_ranking_log_rer log_ranking_lag_log_rer log_ranking_lag2_log_rer ///
	    log_rer_emp lag_log_rer_emp lag2_log_rer_emp  ///
		log_rer_skill lag_log_rer_skill lag2_log_rer_skill  ///
		log_rer_wage lag_log_rer_wage lag2_log_rer_wage ///
        log_rer_imp lag_log_rer_imp lag2_log_rer_imp ///
		log_rer_exp lag_log_rer_exp lag2_log_rer_exp ///
		log_rer_dem lag_log_rer_dem lag2_log_rer_dem ///
	    t1 t2 t3 t4 t5 ///
        log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand, absorb(gp) vce(cluster cnpj)
		
		
qui outreg2 log_rer lag_log_rer lag2_log_rer ///
        log_ranking_log_rer log_ranking_lag_log_rer log_ranking_lag2_log_rer ///
	    log_rer_emp lag_log_rer_emp lag2_log_rer_emp  ///
		log_rer_skill lag_log_rer_skill lag2_log_rer_skill  ///
		log_rer_wage lag_log_rer_wage lag2_log_rer_wage ///
        log_rer_imp lag_log_rer_imp lag2_log_rer_imp ///
		log_rer_exp lag_log_rer_exp lag2_log_rer_exp ///
		log_rer_dem lag_log_rer_dem lag2_log_rer_dem ///
	    t1 t2 t3 t4 t5 ///
        log_lag_emp lag_skill log_lag_wage log_lag_imports log_lag_exports log_cgdp log_gdp log_demand using ProductLadderWithLags, append excel bdec(4) bracket ///
        ctitle("Core/NotCore")
				

				
				
* log_rer long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 1(1)3{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,17] = e(b)*a'
matrix sum[2,17] = sqrt(C[1,1])


* bottom_log_rer long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 4(1)6{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,18] = e(b)*a'
matrix sum[2,18] = sqrt(C[1,1])


* log_rer_emp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 7(1)9{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,19] = e(b)*a'
matrix sum[2,19] = sqrt(C[1,1])



* log_rer_skill long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 10(1)12{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,20] = e(b)*a'
matrix sum[2,20] = sqrt(C[1,1])



* log_rer_wage long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 13(1)15{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,21] = e(b)*a'
matrix sum[2,21] = sqrt(C[1,1])



* log_rer_imp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 16(1)18{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,22] = e(b)*a'
matrix sum[2,22] = sqrt(C[1,1])


* log_rer_exp long-run
matrix V = e(V)
matrix a = J(1,38,0)
forvalues i = 19(1)21{
	matrix a[1,`i'] = 1
}
matrix C = a*V*a'
matrix sum[1,23] = e(b)*a'
matrix sum[2,23] = sqrt(C[1,1])				

clear 

qui svmat sum

cd "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Results"

outsheet _all using ResponseProdLadderLags.csv, comma replace

clear
