/*** LIBRARY PATHS ***/
libname exp 'C:\Data\SECEX\Bases\Exportacao';
libname datalib 'C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data' ;
libname corr 'C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Correspondance' ;


/***********************************************************************************/
/*Aggregate Value and Quantity of Exports at the firm-product-destination level    */
/***********************************************************************************/

proc sort data = corr.ncm9602_final ; by ncm1996 ; run ;


%macro Aggregate9600(start = , stop = ) ;

	%do t = &start %to &stop ;

		%let s = %substr(&t,3,2) ;

		data exp&s. (drop = ncm) ;
			set exp.exp&s. ;
			ncm1996 = input(ncm,8.) ;
		run ;

		proc sort data = exp&s. ; by ncm1996 ; run ;

		data exp&s. ;
			merge exp&s. (in = a) corr.ncm9602_final ;
			by ncm1996 ;
			if a ;
			if group96 = . then ncm = ncm1996 ;
			if group96 ~= . then ncm = group96 ;
		run ;

		proc sort data = exp&s. ; by cnpj8 ncm pais ano ; run ;

		proc means data = exp&s. noprint ;
			var valor qtd peso ;
   			by cnpj8 ncm pais ano ;
   			output out = Exp&s.Agg (drop = _type_ _freq_)
			sum = ValorAgg QtdAgg PesoAgg ;
		run;

		data Exp&s.Agg ;
			set Exp&s.Agg ;
			if PesoAgg > 0 then UnitValue1 = ValorAgg / PesoAgg ;
			else UnitValue1 = . ;
			if QtdAgg > 0 then UnitValue2 = ValorAgg / QtdAgg ;
			else UnitValue2 = ValorAgg / . ;
			if length(compress(cnpj8)) ~= 8 then delete ;
		run ;

		proc sort data = Exp&s.Agg ; by cnpj8 ncm pais ano; run ;

	%end;
%mend;

%Aggregate9600(start=1997,stop=2000) ;



proc sort data = corr.ncm9602_final ; by ncm2002 ; run ;

%macro Aggregate0206(start = , stop = ) ;

	%do t = &start %to &stop ;

		%let s = %substr(&t,3,2) ;

		data exp&s. (drop = ncm) ;
			set exp.exp&s. ;
			ncm2002 = input(ncm,8.) ;
		run ;

		proc sort data = exp&s. ; by ncm2002 ; run ;

		data exp&s. ;
			merge exp&s. (in = a) corr.ncm9602_final ;
			by ncm2002 ;
			if a ;
			if group96 = . then ncm = ncm2002 ;
			if group96 ~= . then ncm = group96 ;
		run ;

		proc sort data = exp&s. ; by cnpj8 ncm pais ano ; run ;

		proc means data = exp&s. noprint ;
			var valor qtd peso ;
   			by cnpj8 ncm pais ano ;
   			output out = Exp&s.Agg (drop = _type_ _freq_)
			sum = ValorAgg QtdAgg PesoAgg ;
		run;

		data Exp&s.Agg ;
			set Exp&s.Agg ;
			if PesoAgg > 0 then UnitValue1 = ValorAgg / PesoAgg ;
			else UnitValue1 = . ;
			if QtdAgg > 0 then UnitValue2 = ValorAgg / QtdAgg ;
			else UnitValue2 = ValorAgg / . ;
			if length(compress(cnpj8)) ~= 8 then delete ;
		run ;

		proc sort data = Exp&s.Agg ; by cnpj8 ncm pais ano; run ;

	%end;
%mend;


%Aggregate0206(start=2002,stop=2006) ;




/**************************************************************/
/**************************************************************/

proc sort data = exp.exp01   ; by ano mes ncm pais uf valor ;
proc sort data = exp.exp01_a ; by ano mes ncm pais uf valor ;


data exp01 (drop = porto tp_op exportadora unidade uf mes quantidade) ;
	merge exp.exp01 (in = a) exp.exp01_a ;
	by ano mes ncm pais uf valor ;
	if a ;
	if length(compress(cnpj8)) ~= 8 then delete ;
	Qtd = quantidade ;
run ;




proc sort data = corr.ncm9602_final ; by ncm1996 ; run ;

data exp01 (drop = ncm) ;
	set exp01 ;
	ncm1996 = input(ncm,8.) ;
run ;

proc sort data = exp01 ; by ncm1996 ; run ;

data exp01 ;
	merge exp01 (in = a) corr.ncm9602_final ;
	by ncm1996 ;
	if a ;
	if group96 = . then ncm = ncm1996 ;
	if group96 ~= . then ncm = group96 ;
run ;





proc sort data = exp01 ; by cnpj8 ncm pais ano ; run ;

proc means data = exp01 noprint ;
	var valor qtd peso ;
   	by cnpj8 ncm pais ano ;
   	output out = Exp01Agg (drop = _type_ _freq_)
	sum = ValorAgg QtdAgg PesoAgg ;
run;

data Exp01Agg ;
	set Exp01Agg ;
	if PesoAgg > 0 then UnitValue1 = ValorAgg / PesoAgg ;
	else UnitValue1 = . ;
	if QtdAgg > 0 then UnitValue2 = ValorAgg / QtdAgg ;
	else UnitValue2 = ValorAgg / . ;
	if length(compress(cnpj8)) ~= 8 then delete ;
run ;

proc sort data = Exp01Agg ; by cnpj8 ncm pais ano; run ;


data UnitValues ;
	set Exp97Agg Exp98Agg Exp99Agg Exp00Agg Exp01Agg Exp02Agg Exp03Agg Exp04Agg 
 		Exp05Agg Exp06Agg ;
	if UnitValue1 = . and UnitValue2 = . then delete ;
run ;

proc delete data = Exp97Agg Exp98Agg Exp99Agg Exp00Agg Exp01Agg Exp02Agg Exp03Agg Exp04Agg 
 				   Exp05Agg Exp06Agg ;
run ;















/******************************************************************/
/*Correspondance between NCM1996 and NCM2002                      */
/******************************************************************/

proc sort data = corr.ncm9602_final ; by ncm1996 ; run ;

%macro Append9600(start = , stop = ) ;

	%do t = &start %to &stop ;

		%let s = %substr(&t,3,2) ;

		data exp&s. (keep = cnpj ncm1996 ano qtd peso valor pais) ;
			set exp.exp&s. ;
			ncm1996 = input(ncm,8.) ;
		run ;

		proc sort data = exp&s. ; by ncm1996 ; run ;

		data exp&s. ;
			merge exp&s. (in = a) corr.ncm9602_final ;
			by ncm1996 ;
			if a ;
			if group96 = . then ncm = ncm1996 ;
			if group96 ~= . then ncm = group96 ;
		run ;

	%end ;

%mend ;

%Append9600(start=1997,stop=2000) ;




proc sort data = corr.ncm9602_final ; by ncm2002 ; run ;

%macro Append0206(start = , stop = ) ;

	%do t = &start %to &stop ;

		%let s = %substr(&t,3,2) ;

		data exp&s. (keep = cnpj ncm2002 ano qtd peso valor pais) ;
			set exp.exp&s. ;
			ncm2002 = input(ncm,8.) ;
		run ;

		proc sort data = exp&s. ; by ncm2002 ; run ;

		data exp&s. ;
			merge exp&s. (in = a) corr.ncm9602_final ;
			by ncm2002 ;
			if a ;
			if group96 = . then ncm = ncm2002 ;
			if group96 ~= . then ncm = group96 ;
		run ;

	%end ;

%mend ;

%Append0206(start=2002,stop=2006) ;


proc sort data = exp.exp01   ; by ano mes ncm pais uf valor ;
proc sort data = exp.exp01_a ; by ano mes ncm pais uf valor ;


data exp01 (keep = cnpj ncm ano qtd peso valor pais) ;
	merge exp.exp01 (in = a) exp.exp01_a ;
	by ano mes ncm pais uf valor ;
	if a ;
	if length(compress(cnpj8)) ~= 8 then delete ;
	Qtd = quantidade ;
run ;


data exp01 (keep = cnpj ncm1996 ano qtd peso valor pais) ;
	set exp01 ;
		ncm1996 = input(ncm,8.) ;
run ;

proc sort data = exp01 ; by ncm1996 ; run ;

proc sort data = corr.ncm9602_final ; by ncm1996 ; run ;

data exp01 ;
	merge exp01 (in = a) corr.ncm9602_final ;
	by ncm1996 ;
	if a ;
	if group96 = . then ncm = ncm1996 ;
	if group96 ~= . then ncm = group96 ;
run ;



data AllExports ;
	set exp97 exp98 exp99 exp00 exp01 exp02 exp03 exp04 exp05 exp06 ;
run ;




/******************************************************************************/
/*Construct the "Natural Measures"                                            */
/******************************************************************************/

data AllExports ;
	set AllExports ;

	report_qtd = 0 ;
	report_peso = 0 ;

/*Flag transactions reported in quantity and/or weight*/
	if qtd ~= 0 and qtd ~= . then report_qtd = 1 ;
	if peso ~= 0 and peso ~= . then report_peso = 1 ;

run ;


proc sort data = AllExports ; by ncm ; run ;


/*Sum (weight by value) across firms, destinations and years */
/*the flags for reporting quantity and for reporting weight*/

proc means noprint data = AllExports  sumsize = max ;
	by ncm ;
	weight valor ;
	output out = natural_measure (drop = _TYPE_ _FREQ_)
	sum(report_qtd report_peso) = report_qtd report_peso ;
run ;


/*Select the most frequently reported measure of unit*/

data natural_measure (drop = report_qtd report_peso) ;
	set natural_measure ;

	if report_peso >= report_qtd then natural_measure1 = "PESO" ;
	if report_peso < report_qtd then natural_measure1 = "QTD" ;

	if report_peso > report_qtd then natural_measure2 = "PESO" ;
	if report_peso <= report_qtd then natural_measure2 = "QTD" ;

run ;



proc sort data = UnitValues ; by ncm ; run ;
proc sort data = natural_measure ; by ncm ; run ;

data datalib.UnitValues (drop = ano cnpj8) ;
	merge UnitValues (in = a) Natural_Measure ;
	by ncm ;
	if a ;
	year = input(ano,8.) ;
	cnpj = cnpj8 ;
run ;


data ncm1996cnae (keep = ncm cnae1996) ;
	set corr.ncm1996cnae ;
	ncm = input(ncm1996,8.) ;
	cnae1996 = cnae2 ;
run ;

data ncm2002cnae (keep = ncm cnae2002) ;
	set corr.ncm2002cnae ;
	ncm = input(ncm2002,8.) ;
	cnae2002 = cnae2 ;
run ;

proc sort data = ncm1996cnae ; by ncm ; run ;

proc sort data = ncm2002cnae ; by ncm ; run ;

proc sort data = datalib.UnitValues ; by ncm ; run ;

data datalib.UnitValues (drop = cnae2002 cnae1996) ;
	merge datalib.UnitValues (in = a) ncm1996cnae ncm2002cnae ;
	by ncm ;
	if a ;
	cnaeprod = cnae1996 ;
	if cnae1996 = "" then cnaeprod = cnae2002 ;
run ;







/**********************************************************************************************/
/*Impute CNAE codes for those products that changed NCM classification between 1996 and 2002  */
/**********************************************************************************************/

data CNAEPROD (keep = ncm1996 group96 valor); 
	set AllExports ;
	if group96 ~= . ;
run ;

data ncm1996cnae (keep = ncm1996 cnae1996) ;
	set corr.ncm1996cnae (rename = ncm1996 = ncm) ;
	cnae1996 = cnae2 ;
	ncm1996 = input(ncm,8.) ;
run ;

proc sort data = CNAEPROD ; by group96 ncm1996 ; run ;


proc means data = CNAEPROD noprint ;
	var valor ;
   	by group96 ncm1996 ;
   	output out = CNAEPROD (drop = _type_ _freq_)
	sum = Valor ;
run;

proc sort data = CNAEPROD ; by ncm1996 ; run ;
proc sort data = ncm1996cnae ; by ncm1996 ; run ;

data CNAEPROD ;
	merge CNAEPROD (in = a) ncm1996cnae ;
	by ncm1996 ;
	if a ;
run ;

proc sort data = CNAEPROD ; by group96 ncm1996 ; run ;

data CNAEPROD (keep = ncm cnae_aux) ;
	set CNAEPROD ;
	by group96 ;
	if first.group96 ;
	cnae_aux = cnae1996 ;
	ncm = group96 ;
run ;


proc sort data = datalib.UnitValues ; by ncm ; run ;
proc sort data = CNAEPROD ; by ncm ; run ;

data datalib.UnitValues (drop = cnae_aux);
	merge datalib.UnitValues (in = a) CNAEPROD ;
	by ncm ;
	if cnae_aux ~= "" then cnaeprod = cnae_aux ;
run ;
