/*==============================================================*/
/*==============================================================*/
/*This SAS file constructs bilateral real exchange rates.*/
/*Source is PWT data.*/
/*RER = ((Real/USD) / PPP_BRA) / ((Foreign/USD) / PPP_FOR)*/
/**/
/*In the end, it merges RER data to the Firms-Exports data*/
/*==============================================================*/
/*==============================================================*/


/*======================================*/
/*Library Name*/
/*======================================*/

libname pwt "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\PWT" ;
libname datalib "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data" ;



/*===========================================*/
/*Construction of Real Exchange Rates (RER)*/
/*XRAT = Foreign Currency / USD*/
/*===========================================*/

data RS_USD_XRAT (drop = country_isocode XRAT PPP) ;
	set pwt.pwt (keep = country_isocode year XRAT PPP) ;

	if country_isocode = "BRA" ;

/*	Reais per US Dollar Exchange Rate*/
	RS_USD_XRAT = XRAT ;

/*	PPP Deflator*/
	PPP_BRA = PPP ;

run ;

proc sort data = RS_USD_XRAT ; by year ; run ;

proc sort data = pwt.pwt ; by year ; run ;



data RER (keep = country_isocode year cgdp POP RER NomER) ;
	merge pwt.pwt (in = a) RS_USD_XRAT ;
	by year ;

/*	Reais per Foreign Currency Exchange Rate*/
	RER = (RS_USD_XRAT / PPP_BRA) / (XRAT / PPP) ;

	NomER = RS_USD_XRAT / XRAT ;
     
run ;
	



/*===============================================================================*/
/*Merge Firms-Exports data with the PWT to Secex country code conversion table*/
/*===============================================================================*/

proc sort data = datalib.UnitValues_Firms ; by pais ; run ;
proc sort data = pwt.PWT_Secex ; by pais ; run ;

data UnitValues_Firms (drop = CNAE imputed); 
	merge datalib.UnitValues_Firms (in = a) pwt.PWT_Secex ;
	by pais ;
	if a ;
	CNAEFIRM = CNAE ;
run ;



/*========================================*/
/*Merge RER with the Exports-Firms Data*/
/*========================================*/

proc sort data = UnitValues_Firms ; by country_isocode year ; run ;
proc sort data = RER ; by country_isocode year ; run ;


data UnitValues_Firms_RER ;
	merge UnitValues_Firms (in = a) RER ;
	by country_isocode year ;
	if a ;
run ;


proc sort data = UnitValues_Firms_RER ; by country_isocode year ; run ;

/*=======================*/
/*Construct lag RER's*/
/*=======================*/

data lag_RER (keep = country_isocode year lag_RER) ;
	set RER ;
	year = year + 1 ;
	lag_RER = RER ;
run ;

data lag2_RER (keep = country_isocode year lag2_RER) ;
	set RER ;
	year = year + 2 ;
	lag2_RER = RER ;
run ;

data lag3_RER (keep = country_isocode year lag3_RER) ;
	set RER ;
	year = year + 3 ;
	lag3_RER = RER ;
run ;

proc sort data = lag_RER  ; by country_isocode year ; run ;
proc sort data = lag2_RER ; by country_isocode year ; run ;
proc sort data = lag3_RER ; by country_isocode year ; run ;

PROC EXPORT DATA = lag_RER
	OUTFILE= "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data\
lag_RER.dta" 
    DBMS=DTA REPLACE;
RUN;

PROC EXPORT DATA = lag2_RER
	OUTFILE= "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data\lag2_RER.dta" 
    DBMS=DTA REPLACE;
RUN;

PROC EXPORT DATA = lag3_RER
	OUTFILE= "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data\lag3_RER.dta" 
    DBMS=DTA REPLACE;
RUN;

data datalib.UnitValues_Firms_RER ;
	merge UnitValues_Firms_RER (in = a) lag_RER lag2_RER ;
	by country_isocode year ;
	if a ;
run ;

proc delete data = lag_RER lag2_RER ; run ;



/*=======================================*/
/*Convert SAS Datasets to Stata Format*/
/*=======================================*/

data UnitValues_Firms_RER (drop = median_wage q1_wage q3_wage cat_educ1 cat_educ2 cat_educ3 cat_educ4) ;
	set datalib.UnitValues_Firms_RER ;
run ;


PROC EXPORT DATA = UnitValues_Firms_RER
	OUTFILE= "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data\UnitValues_Firms_RER.dta" 
    DBMS=DTA REPLACE;
RUN;


proc delete data = UnitValues_Firms_RER ; run ;




/*==========================================*/
/*Dataset with PPP and XRAT only for Brazil*/
/*==========================================*/

data ppp_brazil (keep = year PPP_BRA XRAT_BRA) ;
	set pwt.pwt (keep = XRAT year ppp country_isocode) ;

	if country_isocode = "BRA" ;
	XRAT_BRA = XRAT ;
	PPP_BRA = PPP ;

run ;


PROC EXPORT DATA = ppp_brazil 
	OUTFILE= "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data\ppp_brazil.dta" 
    DBMS=DTA REPLACE;
RUN;




data XRAT_VOL (keep = country_isocode year xrat_vol) ;
	set pwt.pwt ;

	RER = XRAT / PPP ;
	xrat_vol = log(RER) ;
     
run ;


proc sort data = XRAT_VOL ; by country_isocode year ; run ;



proc means data = XRAT_VOL noprint ;
	var xrat_vol ;
   	by country_isocode ;
   	output out = XRAT_VOL (drop = _type_ _freq_)
	var = xrat_vol ;
run;



PROC EXPORT DATA = XRAT_VOL 
	OUTFILE= "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data\XRAT_VOL.dta" 
    DBMS=DTA REPLACE;
RUN;
